
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.9.6',
    'branch_nick': '(detached',
    'revision_id': '001835b24b34caa198591c2932e0242cf518295b',
    'revno': 4641
}
